import enum
# 统计模块，方便根据结果状态分类统计结果
class CommentEnum(enum.Enum):
    # def __new__(cls, value, description):
    #     print('CommentEnum __new__')
    #     obj = object.__new__(cls)
    #     obj._value_ = value
    #     obj._description = description
    #     return obj

    def __init__(self, value, description):
        self._value_ = value
        self._description = description

    @property
    def value(self):
        return self._value_

    @property
    def description(self):
        return self._description


class Statistics:
    def __init__(self):
        self.result_dict: dict[CommentEnum,int] = {}

    def increase(self,key:CommentEnum):
        """ 增加指定enum key的计数值 +1 """
        if key not in self.result_dict:
            self.result_dict[key] = 0
        self.result_dict[key] += 1
    def format(self, sep=' '):
        """格式化输出 各个 enum key 的 计数结果，使用 description 属性展示"""
        strseg = []
        for k,v in self.result_dict.items():
            strseg.append('{} -> {}个'.format(k.description,v))
        return sep.join(strseg)
    def get_count(self,key:CommentEnum):
        """ 获取指定enum key的计数 """
        count = 0
        if key in self.result_dict:
            count = self.result_dict[key]
        return count



import unittest

import hu2.cfg2
from hu2.email2 import Email,get_email_head

cfg_info = hu2.cfg2.ConfigInfo("test_email2_config.ini")

class TestEmail(unittest.TestCase):
    def test_email_head(self):
        h = [get_email_head('46133_7831中@qq.com'),
             get_email_head(None),
             get_email_head('None'),
             get_email_head('None@2@4'),
             ]
        print(h)

        pass
    def test_email2(self):
        eml = Email('13733160671@139.com','e991cc37c634941d1c00','smtp.139.com')

        eml.send(to_emails=['13733160671@139.com','461337831@qq.com'],
                 subject='检测任务说明3',
                 content='第三个检测到目前输入的原文和译文目标语种均为英文，已自动为您转换为英文翻译成中文的服务根据输入的原文 "increase"'
             )

    def test_cfg_email2(self):
        eml = cfg_info.create_email()
        eml.send(to_emails=['461337831@qq.com'],
                 subject='检测任务说明4',
                 content='第四个检测到目前输入的原文和译文目标语种均为英文，已自动为您转换为英文翻译成中文的服务根据输入的原文 "increase"'
                )

if __name__ == '__main__':
    unittest.main()